==> owncloud-tasks_0.7.1.orig.tar.gz: tasks-0.7.1/l10n/hu_HU.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Feladatok",
    "Due yesterday" : "Tegnapi teendök",
    "Due today" : "Mai teendök",
    "Due tomorrow" : "Holnapi teendök",
    "Due on" : "Esedékes",
    "Started yesterday" : "Megkezdve tegnap",
    "Starts today" : "Kezdés ma",
    "Starts tomorrow" : "Kezdés holnap",
    "Started on" : "Megkezdve",
    "Starts on" : "Kezdödik",
    "[Remind me yesterday at ]HH:mm" : "[Emlékeztess holnap ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Emlékeztess ma ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Emlékeztess holnap ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Emlékeztess ]MMM DD, YYYY,HH:mm[ kor ]",
    "Yesterday" : "Tegnap",
    "Today" : "Ma",
    "Tomorrow" : "Holnap",
    "in %s" : "itt:  %s",
    "%s ago" : "%s ezelött",
    "seconds" : "másodpercek",
    "a minute" : "perc",
    "%d minutes" : "%d perc",
    "an hour" : "óra",
    "%d hours" : "%d órák",
    "a day" : "Nap",
    "%d days" : "%d napok",
    "a month" : "Hónap",
    "%d months" : "%d hónapok",
    "a year" : "Év",
    "%d years" : "%d évek",
    "Hours" : "Órák",
    "Minutes" : "Percek",
    "week" : "hét",
    "weeks" : "hetek",
    "day" : "nap",
    "days" : "nap",
    "hour" : "óra",
    "hours" : "órák",
    "minute" : "perc",
    "minutes" : "percek",
    "second" : "másodperc",
    "before beginning" : "kezdés elött",
    "after beginning" : "kezdés után",
    "before end" : "Befejezés elött",
    "after end" : "Befejezés után",
    "Comment" : "Komment",
    "Add a comment" : "Komment hozzáadása",
    "This will delete the Calendar \"%s\" and all of its entries." : "Ez törölni fogja a Naptárat \"%s\" és az összes bejegyzést.",
    "The name \"%s\" is already used." : "Ez a név \"%s\" már foglalt.",
    "An empty name is not allowed." : "Az üres név nem engedélyezett.",
    "Hidden" : "Rejtett",
    "Visible" : "Látható",
    "Automatic" : "Autómatikus",
    "Sunday" : "vasárnap",
    "Monday" : "hétfő",
    "Tuesday" : "kedd",
    "Wednesday" : "szerda",
    "Thursday" : "csütörtök",
    "Friday" : "péntek",
    "Saturday" : "szombat",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n befejezett feladat","%n befejezett feladat"],
    "Set due date" : "Lejárati dátum beállítása",
    "%s %% completed" : "%s %% befejezve",
    "Remind me" : "Emlékeztess",
    "at the end" : "a végénél",
    "at the beginning" : "az elején",
    "Set start date" : "Kezdő dátum beállítása",
    "Important" : "Fontos",
    "Week" : "Hét",
    "All" : "Mind",
    "Current" : "Jelenlegi",
    "Completed" : "Befejezve",
    "Add List..." : "Lista hozzáadása",
    "New List" : "Új lista",
    "Start of week" : "A hét első napja"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-tasks_0.8.1.orig.tar.gz: tasks-0.8.1/l10n/hu_HU.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Feladatok",
    "Tasks app is unavailable because the calendar is not installed" : "A Feladatok alkalmazás nem elérhető, mert a naptár nincs telepítve",
    "Due yesterday" : "Tegnapi teendök",
    "Due today" : "Mai teendök",
    "Due tomorrow" : "Holnapi teendök",
    "Due on" : "Esedékes",
    "Started yesterday" : "Megkezdve tegnap",
    "Starts today" : "Kezdés ma",
    "Starts tomorrow" : "Kezdés holnap",
    "Started on" : "Megkezdve",
    "Starts on" : "Kezdödik",
    "[Remind me yesterday at ]HH:mm" : "[Emlékeztess holnap ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Emlékeztess ma ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Emlékeztess holnap ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Emlékeztess ]MMM DD, YYYY,HH:mm[ kor ]",
    "Yesterday" : "Tegnap",
    "Today" : "Ma",
    "Tomorrow" : "Holnap",
    "in %s" : "itt:  %s",
    "%s ago" : "%s ezelött",
    "seconds" : "másodperc",
    "a minute" : "perc",
    "%d minutes" : "%d perc",
    "an hour" : "óra",
    "%d hours" : "%d órák",
    "a day" : "Nap",
    "%d days" : "%d nap",
    "a month" : "Hónap",
    "%d months" : "%d hónap",
    "a year" : "Év",
    "%d years" : "%d évek",
    "Hours" : "Órák",
    "Minutes" : "Perc",
    "week" : "hét",
    "weeks" : "hetek",
    "day" : "nap",
    "days" : "nap",
    "hour" : "óra",
    "hours" : "órák",
    "minute" : "perc",
    "minutes" : "perc",
    "second" : "másodperc",
    "before beginning" : "kezdés elött",
    "after beginning" : "kezdés után",
    "before end" : "Befejezés elött",
    "after end" : "Befejezés után",
    "Comment" : "Komment",
    "Add a comment" : "Komment hozzáadása",
    "This will delete the Calendar \"%s\" and all of its entries." : "Ez törölni fogja a Naptárat \"%s\" és az összes bejegyzést.",
    "The name \"%s\" is already used." : "Ez a név \"%s\" már foglalt.",
    "An empty name is not allowed." : "Az üres név nem engedélyezett.",
    "Hidden" : "Rejtett",
    "Visible" : "Látható",
    "Automatic" : "Autómatikus",
    "Sunday" : "vasárnap",
    "Monday" : "hétfő",
    "Tuesday" : "kedd",
    "Wednesday" : "szerda",
    "Thursday" : "csütörtök",
    "Friday" : "péntek",
    "Saturday" : "szombat",
    "Add an important item in \"%s\"..." : "Fontos elem hozzáadása ebben: %s...",
    "Add an item due today in \"%s\"..." : "Elem hozzáadása ma ebben: %s...",
    "Add an item in \"%s\"..." : "Elem hozzáadása ebben: %s...",
    "Add a current item in \"%s\"..." : "Jelenlegi elem hozzáadása ebben: %s...",
    "Add a subtask to \"%s\"..." : "Részfeladat hozzáadás ehhez: \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n befejezett feladat","%n befejezett feladat"],
    "Set due date" : "Lejárati dátum beállítása",
    "%s %% completed" : "%s %% befejezve",
    "priority %s: " : "prioritás %s:",
    "high" : "magas",
    "medium" : "közepes",
    "low" : "alacsony",
    "no priority assigned" : "nincs prioritás beállítva",
    "Remind me" : "Emlékeztess",
    "at the end" : "a végénél",
    "at the beginning" : "az elején",
    "Set start date" : "Kezdő dátum beállítása",
    "Important" : "Fontos",
    "Week" : "Hét",
    "All" : "Mind",
    "Current" : "Jelenlegi",
    "Completed" : "Befejezve",
    "rename" : "átnevezés",
    "delete" : "törlés",
    "Add List..." : "Lista hozzáadása",
    "New List" : "Új lista",
    "Settings" : "Beállítások",
    "Start of week" : "A hét első napja",
    "Visibility of Smart Collections" : "Okos gyűjtemény láthatósága",
    "Load remaining completed tasks." : "Hátralévő befejezett feladatok betöltése.",
    "(New category)" : "(Új kategória)",
    "Select categories..." : "Kategória kiválasztása...",
    "Loading the task..." : "Feladat betöltése...",
    "Task not found!" : "Feladat nem található!",
    "add a subtask to" : "részfeladat hozzáadás ehhez"
},
"nplurals=2; plural=(n != 1);");
